==> pandoc-1.19.2.1-114-i686.pkg.tar.xz: usr/share/haskell/register/pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc
version: 1.19.2.1
id: pandoc-1.19.2.1-8Y5SnJ2ekjCGtugksio5yx
key: pandoc-1.19.2.1-8Y5SnJ2ekjCGtugksio5yx
license: GPL
copyright: (c) 2006-2017 John MacFarlane
maintainer: John MacFarlane <jgm@berkeley.edu>
stability: alpha
homepage: http://pandoc.org
synopsis: Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another, and a command-line tool that uses
    this library. It can read several dialects of Markdown and
    (subsets of) HTML, reStructuredText, LaTeX, DocBook,
    MediaWiki markup, TWiki markup, Haddock markup, OPML,
    Emacs Org-Mode, txt2tags, Word Docx, ODT, and Textile, and
    it can write Markdown, reStructuredText, XHTML, HTML 5,
    LaTeX, ConTeXt, DocBook, OPML, TEI, OpenDocument, ODT,
    Word docx, RTF, MediaWiki, DokuWiki, ZimWiki, Textile,
    groff man pages, plain text, Emacs Org-Mode, AsciiDoc,
    Haddock markup, EPUB (v2 and v3), FictionBook2, InDesign ICML,
    and several kinds of HTML/javascript slide shows (S5, Slidy,
    Slideous, DZSlides, reveal.js).
    .
    In contrast to most existing tools for converting Markdown
    to HTML, pandoc has a modular design: it consists of a set of
    readers, which parse text in a given format and produce a
    native representation of the document, and a set of writers,
    which convert this native representation into a target
    format. Thus, adding an input or output format requires
    only adding a reader or writer.
category: Text
author: John MacFarlane <jgm@berkeley.edu>
exposed: True
indefinite: False
exposed-modules:
    Text.Pandoc Text.Pandoc.CSS Text.Pandoc.Error Text.Pandoc.MediaBag
    Text.Pandoc.Options Text.Pandoc.PDF Text.Pandoc.Pretty
    Text.Pandoc.Process Text.Pandoc.Readers.CommonMark
    Text.Pandoc.Readers.DocBook Text.Pandoc.Readers.Docx
    Text.Pandoc.Readers.EPUB Text.Pandoc.Readers.HTML
    Text.Pandoc.Readers.Haddock Text.Pandoc.Readers.LaTeX
    Text.Pandoc.Readers.Markdown Text.Pandoc.Readers.MediaWiki
    Text.Pandoc.Readers.Native Text.Pandoc.Readers.OPML
    Text.Pandoc.Readers.Odt Text.Pandoc.Readers.Org
    Text.Pandoc.Readers.RST Text.Pandoc.Readers.TWiki
    Text.Pandoc.Readers.TeXMath Text.Pandoc.Readers.Textile
    Text.Pandoc.Readers.Txt2Tags Text.Pandoc.SelfContained
    Text.Pandoc.Shared Text.Pandoc.Templates Text.Pandoc.UTF8
    Text.Pandoc.Writers.AsciiDoc Text.Pandoc.Writers.CommonMark
    Text.Pandoc.Writers.ConTeXt Text.Pandoc.Writers.Custom
    Text.Pandoc.Writers.Docbook Text.Pandoc.Writers.Docx
    Text.Pandoc.Writers.DokuWiki Text.Pandoc.Writers.EPUB
    Text.Pandoc.Writers.FB2 Text.Pandoc.Writers.HTML
    Text.Pandoc.Writers.Haddock Text.Pandoc.Writers.ICML
    Text.Pandoc.Writers.LaTeX Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.MediaWiki
    Text.Pandoc.Writers.Native Text.Pandoc.Writers.ODT
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.RST
    Text.Pandoc.Writers.RTF Text.Pandoc.Writers.TEI
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.ZimWiki Text.Pandoc.XML
hidden-modules: Text.Pandoc.Readers.Docx.Lists
                Text.Pandoc.Readers.Docx.Combine Text.Pandoc.Readers.Docx.Parse
                Text.Pandoc.Readers.Docx.Util Text.Pandoc.Readers.Docx.StyleMap
                Text.Pandoc.Readers.Odt.Base Text.Pandoc.Readers.Odt.Namespaces
                Text.Pandoc.Readers.Odt.StyleReader
                Text.Pandoc.Readers.Odt.ContentReader
                Text.Pandoc.Readers.Odt.Generic.Fallible
                Text.Pandoc.Readers.Odt.Generic.SetMap
                Text.Pandoc.Readers.Odt.Generic.Utils
                Text.Pandoc.Readers.Odt.Generic.Namespaces
                Text.Pandoc.Readers.Odt.Generic.XMLConverter
                Text.Pandoc.Readers.Odt.Arrows.State
                Text.Pandoc.Readers.Odt.Arrows.Utils
                Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
                Text.Pandoc.Readers.Org.ExportSettings
                Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
                Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
                Text.Pandoc.Readers.Org.Shared Text.Pandoc.Writers.Shared
                Text.Pandoc.Asciify Text.Pandoc.MIME Text.Pandoc.Emoji
                Text.Pandoc.Parsing Text.Pandoc.UUID Text.Pandoc.ImageSize
                Text.Pandoc.Slides Text.Pandoc.Highlighting Text.Pandoc.Compat.Time
                Paths_pandoc
abi: 0ab7a06b79f7d1108cd4299df91fa5c8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-1.19.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-1.19.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc
hs-libraries: HSpandoc-1.19.2.1-8Y5SnJ2ekjCGtugksio5yx
depends:
    base-4.10.0.0 syb-0.7-2rRPTNxBP6YFePrCXw4i2o containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN array-0.5.2.0
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 filepath-1.4.1.2 process-1.6.1.0
    directory-1.3.0.2 bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    zip-archive-0.3.1.1-CZhWVZnrHky8oZZ6YlWuu5
    HTTP-4000.3.7-Hw6XepIHeicKJxUXQPE0PZ
    texmath-0.9.4.2-4juxRn0R1HI6r5xpDNY1h2
    xml-1.3.14-5OPJvPT6yGP6QU1NbG18WH random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    extensible-exceptions-0.1.1.4-KvghdEZV2En1ybNKCTCQ1Q
    pandoc-types-1.17.1-90yN9xvRX34H7CenrmN1KH
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    skylighting-0.1.1.5-GoewI62Zxc73WuE6B3e1aU
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    yaml-0.8.23.3-5PA6FoFimacABkGYYUI5Gr
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    hslua-0.4.1-EDDF0sBP73XH5Dr7SVpJ01 binary-0.8.5.1
    SHA-1.6.4.2-CLjgfR8MPKbGDDn0VxSSuZ
    haddock-library-1.4.5-1OmnnNPZUScA7ST5GunZse
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h deepseq-1.4.3.0
    JuicyPixels-3.2.8.3-7KzXsiQSvWGDXmMD0ZXfuB
    filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4
    cmark-0.5.6-3XSIcG4srepBYUTysvXhLF
    doctemplates-0.1.0.2-JTL9JlCLRfe2kOEGsf5xDr ghc-prim-0.5.1.0
    time-1.8.0.2 network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             array-0.5.2.0=044554210403f250e868a2183de060a9
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             zip-archive-0.3.1.1-CZhWVZnrHky8oZZ6YlWuu5=501e3ecfee50c6fe29be73a20486bd3f
             HTTP-4000.3.7-Hw6XepIHeicKJxUXQPE0PZ=b3b11e7e23a8d9c723cc7c83fcff6efd
             texmath-0.9.4.2-4juxRn0R1HI6r5xpDNY1h2=fda9441f7ec7ab8efd6abb4c43dcca89
             xml-1.3.14-5OPJvPT6yGP6QU1NbG18WH=30b01491b45ac2b0771399f94ed98fcc
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             extensible-exceptions-0.1.1.4-KvghdEZV2En1ybNKCTCQ1Q=a2b11a35823568844fa9dbca80798092
             pandoc-types-1.17.1-90yN9xvRX34H7CenrmN1KH=747f24f40d86914da38e8d4b759bfa13
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft=3fbcc782bd8302af2fafeef32df01fde
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=c1d55c3251ed960ccd96b402a1d90259
             skylighting-0.1.1.5-GoewI62Zxc73WuE6B3e1aU=90952027dcf5bf03ef4f547a462c4003
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             yaml-0.8.23.3-5PA6FoFimacABkGYYUI5Gr=3efef415fb37938945c14dfc2fd6675d
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             hslua-0.4.1-EDDF0sBP73XH5Dr7SVpJ01=54d938cdffc94f170e69d405597b39f9
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             SHA-1.6.4.2-CLjgfR8MPKbGDDn0VxSSuZ=8e6ca1f753dcb71923c94c0d5ca3f49e
             haddock-library-1.4.5-1OmnnNPZUScA7ST5GunZse=266947595fe64d171b570ef5c38fb90e
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=9b88a29fc517c1a42f17e665c48bfa0f
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             JuicyPixels-3.2.8.3-7KzXsiQSvWGDXmMD0ZXfuB=bbcb26582db7df34065405a01790a353
             filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4=920d793dfdc12d2f05a040a5aead8798
             cmark-0.5.6-3XSIcG4srepBYUTysvXhLF=a8957c403ec3ecdc2c7e0e636c334ead
             doctemplates-0.1.0.2-JTL9JlCLRfe2kOEGsf5xDr=4e6520bb94c629c1845615185c9f5069
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J=bfd2559218a81acc5cfe715436ea1e49
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
haddock-interfaces: /usr/share/doc/pandoc/html/pandoc.haddock
haddock-html: /usr/share/doc/pandoc/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-1.19.2.1-120-i686.pkg.tar.xz: usr/share/haskell/register/pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc
version: 1.19.2.1
id: pandoc-1.19.2.1-5c3XIfQW0IdI85TPAAmyLk
key: pandoc-1.19.2.1-5c3XIfQW0IdI85TPAAmyLk
license: GPL
copyright: (c) 2006-2017 John MacFarlane
maintainer: John MacFarlane <jgm@berkeley.edu>
stability: alpha
homepage: http://pandoc.org
synopsis: Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another, and a command-line tool that uses
    this library. It can read several dialects of Markdown and
    (subsets of) HTML, reStructuredText, LaTeX, DocBook,
    MediaWiki markup, TWiki markup, Haddock markup, OPML,
    Emacs Org-Mode, txt2tags, Word Docx, ODT, and Textile, and
    it can write Markdown, reStructuredText, XHTML, HTML 5,
    LaTeX, ConTeXt, DocBook, OPML, TEI, OpenDocument, ODT,
    Word docx, RTF, MediaWiki, DokuWiki, ZimWiki, Textile,
    groff man pages, plain text, Emacs Org-Mode, AsciiDoc,
    Haddock markup, EPUB (v2 and v3), FictionBook2, InDesign ICML,
    and several kinds of HTML/javascript slide shows (S5, Slidy,
    Slideous, DZSlides, reveal.js).
    .
    In contrast to most existing tools for converting Markdown
    to HTML, pandoc has a modular design: it consists of a set of
    readers, which parse text in a given format and produce a
    native representation of the document, and a set of writers,
    which convert this native representation into a target
    format. Thus, adding an input or output format requires
    only adding a reader or writer.
category: Text
author: John MacFarlane <jgm@berkeley.edu>
exposed: True
indefinite: False
exposed-modules:
    Text.Pandoc Text.Pandoc.CSS Text.Pandoc.Error Text.Pandoc.MediaBag
    Text.Pandoc.Options Text.Pandoc.PDF Text.Pandoc.Pretty
    Text.Pandoc.Process Text.Pandoc.Readers.CommonMark
    Text.Pandoc.Readers.DocBook Text.Pandoc.Readers.Docx
    Text.Pandoc.Readers.EPUB Text.Pandoc.Readers.HTML
    Text.Pandoc.Readers.Haddock Text.Pandoc.Readers.LaTeX
    Text.Pandoc.Readers.Markdown Text.Pandoc.Readers.MediaWiki
    Text.Pandoc.Readers.Native Text.Pandoc.Readers.OPML
    Text.Pandoc.Readers.Odt Text.Pandoc.Readers.Org
    Text.Pandoc.Readers.RST Text.Pandoc.Readers.TWiki
    Text.Pandoc.Readers.TeXMath Text.Pandoc.Readers.Textile
    Text.Pandoc.Readers.Txt2Tags Text.Pandoc.SelfContained
    Text.Pandoc.Shared Text.Pandoc.Templates Text.Pandoc.UTF8
    Text.Pandoc.Writers.AsciiDoc Text.Pandoc.Writers.CommonMark
    Text.Pandoc.Writers.ConTeXt Text.Pandoc.Writers.Custom
    Text.Pandoc.Writers.Docbook Text.Pandoc.Writers.Docx
    Text.Pandoc.Writers.DokuWiki Text.Pandoc.Writers.EPUB
    Text.Pandoc.Writers.FB2 Text.Pandoc.Writers.HTML
    Text.Pandoc.Writers.Haddock Text.Pandoc.Writers.ICML
    Text.Pandoc.Writers.LaTeX Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.MediaWiki
    Text.Pandoc.Writers.Native Text.Pandoc.Writers.ODT
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.RST
    Text.Pandoc.Writers.RTF Text.Pandoc.Writers.TEI
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.ZimWiki Text.Pandoc.XML
hidden-modules: Text.Pandoc.Readers.Docx.Lists
                Text.Pandoc.Readers.Docx.Combine Text.Pandoc.Readers.Docx.Parse
                Text.Pandoc.Readers.Docx.Util Text.Pandoc.Readers.Docx.StyleMap
                Text.Pandoc.Readers.Odt.Base Text.Pandoc.Readers.Odt.Namespaces
                Text.Pandoc.Readers.Odt.StyleReader
                Text.Pandoc.Readers.Odt.ContentReader
                Text.Pandoc.Readers.Odt.Generic.Fallible
                Text.Pandoc.Readers.Odt.Generic.SetMap
                Text.Pandoc.Readers.Odt.Generic.Utils
                Text.Pandoc.Readers.Odt.Generic.Namespaces
                Text.Pandoc.Readers.Odt.Generic.XMLConverter
                Text.Pandoc.Readers.Odt.Arrows.State
                Text.Pandoc.Readers.Odt.Arrows.Utils
                Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
                Text.Pandoc.Readers.Org.ExportSettings
                Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
                Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
                Text.Pandoc.Readers.Org.Shared Text.Pandoc.Writers.Shared
                Text.Pandoc.Asciify Text.Pandoc.MIME Text.Pandoc.Emoji
                Text.Pandoc.Parsing Text.Pandoc.UUID Text.Pandoc.ImageSize
                Text.Pandoc.Slides Text.Pandoc.Highlighting Text.Pandoc.Compat.Time
                Paths_pandoc
abi: 15812ee9de6001d8940e9a903632f0f3
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-1.19.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/pandoc-1.19.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc
hs-libraries: HSpandoc-1.19.2.1-5c3XIfQW0IdI85TPAAmyLk
depends:
    base-4.10.0.0 syb-0.7-2rRPTNxBP6YFePrCXw4i2o containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN array-0.5.2.0
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 filepath-1.4.1.2 process-1.6.1.0
    directory-1.3.0.2 bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    zip-archive-0.3.1.1-CZhWVZnrHky8oZZ6YlWuu5
    HTTP-4000.3.7-Hw6XepIHeicKJxUXQPE0PZ
    texmath-0.9.4.4-DDxgkBqMdT71t8kEWRuFAs
    xml-1.3.14-5OPJvPT6yGP6QU1NbG18WH random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    extensible-exceptions-0.1.1.4-KvghdEZV2En1ybNKCTCQ1Q
    pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    skylighting-0.1.1.5-2p88d0NgWv3JhcIFejHNl4
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    yaml-0.8.23.3-2QGOHBHHpaurEGLPcLVJG
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    hslua-0.4.1-EDDF0sBP73XH5Dr7SVpJ01 binary-0.8.5.1
    SHA-1.6.4.2-CLjgfR8MPKbGDDn0VxSSuZ
    haddock-library-1.4.5-1OmnnNPZUScA7ST5GunZse
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h deepseq-1.4.3.0
    JuicyPixels-3.2.8.3-7KzXsiQSvWGDXmMD0ZXfuB
    filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4
    cmark-0.5.6-3XSIcG4srepBYUTysvXhLF
    doctemplates-0.1.0.2-AHyJgOjRBDrLS4ctsXMPNe ghc-prim-0.5.1.0
    time-1.8.0.2 network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             array-0.5.2.0=044554210403f250e868a2183de060a9
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             zip-archive-0.3.1.1-CZhWVZnrHky8oZZ6YlWuu5=501e3ecfee50c6fe29be73a20486bd3f
             HTTP-4000.3.7-Hw6XepIHeicKJxUXQPE0PZ=b3b11e7e23a8d9c723cc7c83fcff6efd
             texmath-0.9.4.4-DDxgkBqMdT71t8kEWRuFAs=e80806dccd1f7b311acecd0e2acf11d9
             xml-1.3.14-5OPJvPT6yGP6QU1NbG18WH=30b01491b45ac2b0771399f94ed98fcc
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             extensible-exceptions-0.1.1.4-KvghdEZV2En1ybNKCTCQ1Q=a2b11a35823568844fa9dbca80798092
             pandoc-types-1.17.2-Fl8qYoEQbpODaVFN2ZWOXB=671e07ddd80a4e21a2a78e76900b479f
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             tagsoup-0.14.1-Dd68OXPvIKPH8wN6EGE1ft=3fbcc782bd8302af2fafeef32df01fde
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=c1d55c3251ed960ccd96b402a1d90259
             skylighting-0.1.1.5-2p88d0NgWv3JhcIFejHNl4=536da91a0cc7df2767b3ab7e5153d29f
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             yaml-0.8.23.3-2QGOHBHHpaurEGLPcLVJG=2c546b36221194a2b134d5137464910f
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             hslua-0.4.1-EDDF0sBP73XH5Dr7SVpJ01=54d938cdffc94f170e69d405597b39f9
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             SHA-1.6.4.2-CLjgfR8MPKbGDDn0VxSSuZ=8e6ca1f753dcb71923c94c0d5ca3f49e
             haddock-library-1.4.5-1OmnnNPZUScA7ST5GunZse=266947595fe64d171b570ef5c38fb90e
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=9b88a29fc517c1a42f17e665c48bfa0f
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             JuicyPixels-3.2.8.3-7KzXsiQSvWGDXmMD0ZXfuB=bbcb26582db7df34065405a01790a353
             filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4=920d793dfdc12d2f05a040a5aead8798
             cmark-0.5.6-3XSIcG4srepBYUTysvXhLF=a8957c403ec3ecdc2c7e0e636c334ead
             doctemplates-0.1.0.2-AHyJgOjRBDrLS4ctsXMPNe=1762acedd51cbbbb7e8eb5bab9a3261d
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             http-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK=2c976076a1c68f1c8d224058bac08c04
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
haddock-interfaces: /usr/share/doc/pandoc/html/pandoc.haddock
haddock-html: /usr/share/doc/pandoc/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
